@@ -8,6 +8,7 @@ The module provides several static methods."""
 import sys
 import re
 import multiprocessing
+from multiprocessing import get_context
 from functools import partial
 import warnings
 import logging
@@ -1001,7 +1002,8 @@ def parrallelize_dataframe(df, func, num_cores=None):
 
     # this line breaks the dataframe and gives a list of dataframe pieces
     df_split = np.array_split(df, num_cores)
-    with multiprocessing.Pool(num_cores) as pool:
+    with get_context("spawn").Pool() as pool:
+    # with multiprocessing.Pool(num_cores) as pool:
         df = pd.concat(pool.map(func, df_split), sort=False)
     return df
 
@@ -1023,7 +1025,8 @@ def parrallelize_dataframes(df1, df2, func, num_cores=None):
     df1_split = np.array_split(df1, num_cores)
     df2_split = np.array_split(df2, num_cores)
 
-    with multiprocessing.Pool(num_cores) as pool:
+    with get_context("spawn").Pool() as pool:
+    # with multiprocessing.Pool(num_cores) as pool:
         df_lists = pool.starmap(func, zip(df1_split, df2_split))
 
         df1 = pd.concat((df[0] for df in df_lists), sort=False)
